@@ -921,8 +921,7 @@ class DensityFlow(nn.Module):
         R = np.concatenate(R)
         return R
     
-    def _count(self, zs, library_size=None):
-        concentrate = self._get_expression_response(zs)
+    def _count(self, concentrate, library_size=None):
         if self.loss_func == 'bernoulli':
             #counts = self.sigmoid(concentrate)
             counts = dist.Bernoulli(logits=concentrate).to_event(1).mean
@@ -930,9 +929,6 @@ class DensityFlow(nn.Module):
             rate = concentrate.exp()
             theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
             counts = theta * library_size
-            if self.loss_func == 'negbinomial':
-                total_count = self.decoder_total_count(zs)
-                counts = dist.NegativeBinomial(total_count=total_count, probs=theta).to_event(1).mean
         return counts
     
     def get_counts(self, zs, library_sizes,
@@ -952,8 +948,8 @@ class DensityFlow(nn.Module):
         E = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for Z_batch, L_batch, _ in dataloader:
-                #concentrate = self._get_expression_response(Z_batch)
-                counts = self._count(Z_batch, L_batch)
+                concentrate = self._get_expression_response(Z_batch)
+                counts = self._count(concentrate, L_batch)
                 E.append(tensor_to_numpy(counts))
                 pbar.update(1)
         
